// AboutDlg.h
// (c) 2003-2005 exeal

#ifndef _ABOUT_DLG_H_
#define _ABOUT_DLG_H_
#include "resource.h"
#include "../Manah/Dialog.h"
#include "../Manah/LinkLabel.h"


namespace Alpha {
	///	uo[Wv_CAO
	class CAboutDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_ABOUT> {
		// f[^o
	private:
		Manah::Windows::Controls::CLinkLabel	m_homePageLink;
		Manah::Windows::Controls::CLinkLabel	m_sourceForgeLink;

		// bZ[Wnh
	protected:
		virtual bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);	// WM_COMMAND
		virtual bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);		// WM_INITDIALOG
	};
}

#endif /* _ALPHA_DLG_H_ */

/* [EOF] */